#define LEFT_BRACKET 257
#define RIGHT_BRACKET 258
#define EQUAL 259
#define NEWLINE 260
#define NONWS_STRING 261
#define NONWSEQ_STRING 262
#define QUOTED_NONWSEQ_STRING 263
#ifndef YYSTYPE_DEFINED
#define YYSTYPE_DEFINED
typedef union {
char *strtype;
} YYSTYPE;
#endif /* YYSTYPE_DEFINED */
extern YYSTYPE conf_lval;
